intelmq.bots.parsers.eset package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.eset package

## Submodules

## intelmq.bots.parsers.eset.parser module

intelmq.bots.parsers.eset.parser.BOT

  alias of `intelmq.bots.parsers.eset.parser.ESETParserBot`

class intelmq.bots.parsers.eset.parser.ESETParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse data collected from ESET’s TAXII API

  common_parse(event, line)
  static domains_parse(event, line)
  init()
  parse(report: intelmq.lib.message.Report)

    A basic JSON parser. Assumes a list of objects as input to be yield.

  parse_line(line, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

  recover_line(line: dict) → str

    Reverse of parse for JSON pulses.

    Recovers a fully functional report with only the problematic pulse.

  static urls_parse(event, line)

## Module contents